/* --------------------------------------------------------------------------------------------------------
    Change Log
    - 2022-04-29: Added function to return HREF of items
    - 2022-04-28: Runs createFolder promised now
    -------------------------------------------------------------------------------------------------------- */


const settings  = require("../settings.js");
const fs        = require('fs');
const path      = require('path');


exports.printStart = function printStart(params) {

    console.log();
    console.log('    ' + new Date().toLocaleDateString() + ' ' + new Date().toLocaleTimeString());
    console.log();
    console.log('   ************************************* START *************************************');
    console.log('   ');
    console.log('    SETTINGS');
    console.log('   ---------------------------------------------------------------------------------');
    console.log('    Tenant                        : ' + settings.tenant); 
    console.log('    User Name                     : ' + settings.user); 

    if(params !== null) {
        if(typeof params !== 'undefined') {
            for(param of params) {
                let line = '    ' + param[0];
                for(var i = param[0].length; i < 29; i++) line += ' ';
                line += ' : ' + param[1];
                console.log(line); 
            }
        }
    }

    console.log(); 

}

exports.print = function print(text) {
    console.log('    ' + text);
}

exports.printLine = function printLine() {
    console.log('   ---------------------------------------------------------------------------------');
}

exports.printEnd = function printEnd() {

    console.log();
    console.log('   ************************************** END **************************************');
    console.log();

}

exports.printError = function printError(message) {

    console.log();
    console.log('    !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERROR !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!');
    console.log('    ' + message);
    console.log('    !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!');
    console.log();

}


exports.genItemLink = function genItemLink(wsId, dmsId) {

    return '/api/v3/workspaces/' + wsId + '/items/' + dmsId;

}

exports.genItemHREF = function genItemLink(link) {

    let temp  = link.split('/');
    let wsId  = temp[4];
    let dmsId = temp[6];

    let url = 'https://' + settings.tenant + '.autodeskplm360.net';
        url += '/plm/workspaces/';
        url += wsId;
        url += '/items/itemDetails?view=full&tab=details&itemId=';
        url += 'urn%60adsk,plm%60tenant,workspace,item%60' + settings.tenant.toUpperCase() + ',' + wsId + ',' + dmsId;

    return url;

}


// Create folder if it does not exist
exports.createFolder = function createFolder(pathFolder, logs) {

    return new Promise(function(resolve, reject) {

        if(logs) console.log('    Validating folder ' + pathFolder);

        if (!fs.existsSync(pathFolder))  { 
            if(logs) console.log('    Folder does not exist');
            fs.mkdirSync(pathFolder, true);
            if(logs) console.log('    Folder has been created');
            return resolve();
        } else {
            return resolve();
        }

    });

}


// Delete defined file
exports.deleteFile = function deleteFile(pathFile) {

    fs.stat(pathFile, function(err, stat) {
        if(err == null) fs.unlinkSync(pathFile);
    });

}


// Remove all files in defined folder
exports.clearFolder = function clearFolder(folder) {

    fs.readdir(folder, (err, files) => {
        if (err) throw err;

        for (const file of files) {
            fs.unlink(path.join(folder, file), err => {
            if (err) throw err;
            });
        }
    });

}


// Get date string with double digits
exports.getDateString = function getDateString(date) {

    let result = date.getFullYear();
        result += '-';
        result += (date.getMonth() < 9) ? '0' : '';
        result += (date.getMonth() + 1);
        result += '-';
        result += (date.getDate() < 10) ? '0' : '';
        result += date.getDate();

    return result;

}


// Get date / time string with double digits
exports.getDateTimeString = function getDateTimeString(date) {
    
    let result = date.getFullYear() + '-';
    if(date.getMonth() < 9) result += '0';
    result += (date.getMonth() + 1) + '-';
    if(date.getDate() < 10) result += '0';
    result += date.getDate() + ' ';
    if(date.getHours() < 10) result += '0';
    result += date.getHours() + '-';
    if(date.getMinutes() < 10) result += '0';
    result += date.getMinutes() + '-';
    if(date.getSeconds() < 10) result += '0';
    result += date.getSeconds();

    return result;
    
}


// Create log file
exports.getLogPath = function getLogPath() {
    
    if (!fs.existsSync('../logs')){
        fs.mkdirSync('../logs');
    }
    
    return '../logs/';
    
}
exports.getLogFilePath = function getLogFilePath(name) {
    
    let now     = new Date();
    let month   = doubleDigit(now.getMonth() + 1);
    let day     = doubleDigit(now.getDate());
    let hours   = doubleDigit(now.getHours());
    let minutes = doubleDigit(now.getMinutes());
    let seconds = doubleDigit(now.getSeconds());

    if (!fs.existsSync('../logs')){
        fs.mkdirSync('../logs');
    }
    
    let fileName  = name + ' ';
        fileName += now.getFullYear();
        fileName += '-';
        fileName += month;
        fileName += '-';
        fileName += day;
        fileName += ' ';
        fileName += hours;
        fileName += '-';
        fileName += minutes;
        fileName += '-';
        fileName += seconds;
        fileName += '.txt';
    
    return '../logs/' + fileName;
    
}
function doubleDigit(value) {
        
    let result = value.toString();
    
    if(value < 10) result = '0' + result;
    
    return result;
    
}